==> fwobac-1.2.tar.gz: fwobac-1.2/file_utils.h <==
/* $Id: file_utils.h,v 1.6 2017/08/05 12:12:48 rlr Exp $ */

/*
 * Copyright (c) 2016, 2017 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef _FILE_UTILS_H_
#define _FILE_UTILS_H_


#include <stdio.h>
#include <time.h>


/*
 * int	 touch_file(const char *path, time_t t);
 *
 * If the file specified by path does not exist, it is created.  If the
 * modification time of the specified file is earlier than t, it is updated
 * to t.
 *
 * Returns zero on success, or the relevant errno on failure.
 */
int	 touch_file(const char *, time_t);

/*
 * FILE	*fopen_temp(char *template, const char *mode);
 *
 * Creates and opens a temporary file, with name based on template [in the
 * manner of mkstemp(3)].  The file is opened with the specified mode.
 *
 * On success, the return value is non-NULL and template is changed to the
 * file/path name.  On failure, NULL is returned and the value of template
 * is undefined.
 */
FILE	 *fopen_temp(char *, const char *);


/*
 * int	 delete_dir(char *path);
 *
 * Deletes the directory hierarchy rooted at the given path, stopping on error.
 * Returns zero if and only if no error is detected; otherwise, returns the
 * errno for the (first) error encountered.
 */
int
delete_dir(char *);


#endif /* !_FILE_UTILS_H_ */

==> fwobac-2.1.tar.gz: fwobac-2.1/file_utils.h <==
/* $Id: file_utils.h,v 1.9 2018/06/19 04:44:25 rlr Exp $ */

/*
 * Copyright (c) 2016, 2017, 2018 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef _FILE_UTILS_H_
#define _FILE_UTILS_H_


#include <stdio.h>
#include <time.h>


/*
 * int
 * touch_file(const char *path, time_t t);
 *
 * If the file specified by path does not exist, it is created.  If the
 * modification time of the specified file is earlier than t, it is updated
 * to t.
 *
 * Returns zero on success, or the relevant errno on failure.
 */
int	 touch_file(const char *, time_t);


/*
 * FILE	*
 * fopen_temp(char *template, const char *mode);
 *
 * Creates and opens a temporary file, with name based on template [in the
 * manner of mkstemp(3)].  The file is opened with the specified mode.
 *
 * On success, the return value is non-NULL and template is changed to the
 * file/path name.  On failure, NULL is returned and the value of template
 * is undefined.
 */
FILE	 *fopen_temp(char *, const char *);


/*
 * int
 * delete_dir(char *path);
 *
 * Deletes the directory hierarchy rooted at the given path, stopping on error.
 * Returns zero if and only if no error is detected; otherwise, returns the
 * errno for the (first) error encountered.
 */
int
delete_dir(char *);


#endif /* !_FILE_UTILS_H_ */
